@@ -1,11 +1,11 @@
 package custom
 
-import "github.com/aquasecurity/tfsec/internal/pkg/block"
+import "github.com/aquasecurity/defsec/parsers/terraform"
 
 type customCheckVariables map[string]string
 
 type customContext struct {
-	module    *block.Module
+	module    *terraform.Module
 	variables customCheckVariables
 }
 
@@ -16,14 +16,14 @@ func NewEmptyCustomContext() *customContext {
 	}
 }
 
-func NewCustomContext(module *block.Module) *customContext {
+func NewCustomContext(module *terraform.Module) *customContext {
 	return &customContext{
 		module:    module,
 		variables: make(customCheckVariables),
 	}
 }
 
-func NewCustomContextWithVariables(module *block.Module, variables customCheckVariables) *customContext {
+func NewCustomContextWithVariables(module *terraform.Module, variables customCheckVariables) *customContext {
 	return &customContext{
 		module:    module,
 		variables: variables,
